from stargazing import Stargazing

__all__ = ["main"]


def main():
    """Main entry point for script"""

    stargazing = Stargazing()
    stargazing.start()


if __name__ == "__main__":
    main()
